@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  *
  * Authors: William Jon McCann <mccann@jhu.edu>
  *
@@ -37,21 +37,23 @@
 #include <gdk/gdkx.h>
 #include <X11/XKBlib.h>
 #include <gtk/gtk.h>
-#include <mateconf/mateconf-client.h>
+#include <gio/gio.h>
 
 #ifdef WITH_KBD_LAYOUT_INDICATOR
 #include <libmatekbd/matekbd-indicator.h>
 #endif
 
-#ifdef WITH_LIBMATENOTIFY
-#include <libmatenotify/notify.h>
+#ifdef WITH_LIBNOTIFY
+#include <libnotify/notify.h>
 #endif
 
 #include "gs-lock-plug.h"
 
 #include "gs-debug.h"
 
-#define KEY_LOCK_DIALOG_THEME "/apps/mate-screensaver/lock_dialog_theme"
+#define GSETTINGS_SCHEMA "org.mate.screensaver"
+
+#define KEY_LOCK_DIALOG_THEME "lock-dialog-theme"
 
 #define MDM_FLEXISERVER_COMMAND "mdmflexiserver"
 #define MDM_FLEXISERVER_ARGS    "--startnew Standard"
@@ -1181,7 +1183,7 @@ static void
 submit_note (GtkButton  *button,
              GSLockPlug *plug)
 {
-#ifdef WITH_LIBMATENOTIFY
+#ifdef WITH_LIBNOTIFY
 	char               *text;
 	char                summary[128];
 	char               *escaped_text;
@@ -1202,8 +1204,7 @@ submit_note (GtkButton  *button,
 	tmp = localtime (&t);
 	strftime (summary, 128, "%X", tmp);
 
-	notify_init ("mate-screensaver-dialog");
-	note = notify_notification_new (summary, escaped_text, NULL, NULL);
+	note = notify_notification_new (summary, escaped_text, NULL);
 	notify_notification_set_timeout (note, NOTIFY_EXPIRES_NEVER);
 	notify_notification_show (note, NULL);
 	g_object_unref (note);
@@ -1212,7 +1213,7 @@ submit_note (GtkButton  *button,
 	g_free (escaped_text);
 
 	gs_lock_plug_response (plug, GS_LOCK_PLUG_RESPONSE_CANCEL);
-#endif /* WITH_LIBMATENOTIFY */
+#endif /* WITH_LIBNOTIFY */
 }
 
 static void
@@ -1757,11 +1758,11 @@ static char *
 get_dialog_theme_name (GSLockPlug *plug)
 {
 	char        *name;
-	MateConfClient *client;
+	GSettings *settings;
 
-	client = mateconf_client_get_default ();
-	name = mateconf_client_get_string (client, KEY_LOCK_DIALOG_THEME, NULL);
-	g_object_unref (client);
+	settings = g_settings_new (GSETTINGS_SCHEMA);
+	name = g_settings_get_string (settings, KEY_LOCK_DIALOG_THEME);
+	g_object_unref (settings);
 
 	return name;
 }
@@ -1880,10 +1881,7 @@ on_note_text_buffer_changed (GtkTextBuffer *buffer,
 	int len;
 
 	len = gtk_text_buffer_get_char_count (buffer);
-	if (len > NOTE_BUFFER_MAX_CHARS)
-	{
-		gtk_widget_set_sensitive (plug->priv->note_text_view, FALSE);
-	}
+	gtk_widget_set_sensitive (plug->priv->note_ok_button, len <= NOTE_BUFFER_MAX_CHARS);
 }
 
 static void
@@ -1895,7 +1893,8 @@ gs_lock_plug_init (GSLockPlug *plug)
 
 	clear_clipboards (plug);
 
-#ifdef WITH_LIBMATENOTIFY
+#ifdef WITH_LIBNOTIFY
+	notify_init ("mate-screensaver-dialog");
 	plug->priv->leave_note_enabled = TRUE;
 #else
 	plug->priv->leave_note_enabled = FALSE;
@@ -2082,6 +2081,9 @@ gs_lock_plug_finalize (GObject *object)
 
 	remove_response_idle (plug);
 	remove_cancel_timeout (plug);
+#ifdef WITH_LIBNOTIFY
+	notify_uninit ();
+#endif
 
 	G_OBJECT_CLASS (gs_lock_plug_parent_class)->finalize (object);
 }
